summaryrefslogtreecommitdiffstats
path: root/kmail/secondarywindow.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/secondarywindow.cpp')
-rw-r--r--kmail/secondarywindow.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/kmail/secondarywindow.cpp b/kmail/secondarywindow.cpp
index d2296f43..38f6b32d 100644
--- a/kmail/secondarywindow.cpp
+++ b/kmail/secondarywindow.cpp
@@ -39,7 +39,7 @@ namespace KMail {
//---------------------------------------------------------------------------
SecondaryWindow::SecondaryWindow( const char * name )
- : KMainWindow( 0, name )
+ : TDEMainWindow( 0, name )
{
// Set this to be the group leader for all subdialogs - this means
// modal subdialogs will only affect this window, not the other windows
@@ -62,7 +62,7 @@ namespace KMail {
// if there's a system tray applet then just do what needs to be done if a
// window is closed.
if ( kmkernel->haveSystemTrayApplet() ) {
// BEGIN of code borrowed from KMainWindow::closeEvent
// Save settings if auto-save is enabled, and settings have changed
if ( settingsDirty() && autoSaveSettings() )
saveAutoSaveSettings();
@@ -70,10 +70,10 @@ namespace KMail {
if ( queryClose() ) {
e->accept();
}
// END of code borrowed from KMainWindow::closeEvent
}
else
- KMainWindow::closeEvent( e );
+ TDEMainWindow::closeEvent( e );
}
} // namespace KMail
@@ -62,7 +62,7 @@ namespace KMail {
// window is closed.
if ( kmkernel->haveSystemTrayApplet() ) {
- // BEGIN of code borrowed from KMainWindow::closeEvent
+ // BEGIN of code borrowed from TDEMainWindow::closeEvent
// Save settings if auto-save is enabled, and settings have changed
if ( settingsDirty() && autoSaveSettings() )
@@ -70,10 +70,10 @@ namespace KMail {
e->accept();
}
- // END of code borrowed from KMainWindow::closeEvent
+ // END of code borrowed from TDEMainWindow::closeEvent
}
else